# GeoFinder 
GeoFinder reads the place names in a GEDCOM genealogy file, validates and corrects them and adds their latitude and longitude.  For unrecognized places, it supports wildcard searches and phonetic searches from the 20M entry geoname.org database.  

<a name="features"></a>
## Features  
* Rich place name database from geonames.org optimized for Genealogy including cemeteries, historic locations, and religious locations.
* Designed for correcting large GEDCOM files
* Automatic matching wherever possible adds missing information such as missing state/province or county.
* Cleans up and standardizes placenames
* Output is to a new GEDCOM file
* Adds latitude/longitude 
* Wildcard search
* Phonetic search
* Highlights locations in the US and Canada where the event date is before European settlement
   
[See User Guide Wiki for details](https://github.com/corb555/GeoFinder/wiki/User-Guide)
